@@ -30,14 +30,6 @@ class Point(object):
     def by_method(self):
         return self.__by_method
 
-time = Time()
-index = Index()
-point = Point()
-
-by_methods = [time.by_method,
-              index.by_method,
-              point.by_method]
-
-bys = [time.__class__.__name__,
-       index.__class__.__name__,
-       point.__class__.__name__]
\ No newline at end of file
+by_methods = [Time().by_method,
+              Index().by_method,
+              Point().by_method]
\ No newline at end of file
